Name:		fermilab-conf_ssh-client
Obsoletes:	zz_fermi_ssh_config
Version:	1.0
Release:	1
Summary:	Change ssh_config to utilize Fermilab behavior

Group:		Fermilab
License:	GPL
URL:		http://helpdesk.fnal.gov
Source0:	fermi-conf_ssh-client.sh

BuildRequires:	bash coreutils
BuildArch:	noarch
Requires(post):	augeas >= 0.9.0 policycoreutils coreutils

%description
The default configuration for openssh-client does not take full advantage
of the expected Fermilab openssh-server settings.
This includes X11Forwarding and GSSAPI credential forwarding.
This RPM will update %{_sysconfdir}/ssh/ssh_config to meet Fermilab standards.

Behavior from: CS-doc-1186

%prep


%build


%install
rm -rf %{buildroot}
%{__install} -D %{SOURCE0} %{buildroot}/%{_libexecdir}/%{name}/%{name}.sh

%clean
rm -rf %{buildroot}

%check
bash -n %{buildroot}/%{_libexecdir}/%{name}/%{name}.sh

%files
%defattr(0644,root,root,0755)
%doc
%attr(0750,root,root) %{_libexecdir}/%{name}/%{name}.sh

#####################################################################
%triggerin -p /bin/bash -- openssh-clients

##################### BEGIN Snippet #################################
set -u
TRIGGER_ON_PACKAGE_NAME='openssh-clients'
# The following script snippet attempts to classify why we were called:
#  - on first install of either package, RUN_TRIGGER == "Initial"
#  - on upgrade of _THIS_ package, RUN_TRIGGER == "UpgradeSELF"
#  - on upgrade of the TRIGGERON package, RUN_TRIGGER == "UpgradeTRIGGERON"
#  - on upgrade of the TRIGGERON package but initial install of _THIS_ package, RUN_TRIGGER == "InitialSELFUpgradeTRIGGERON"
#  - on upgrade of the BOTH packages, RUN_TRIGGER == "UPGRADEALL"

CURRENT_INSTALLS_OF_THIS_PACKAGE=${1}
TRIGGER_ON_PACKAGE=${2}

RUN_TRIGGER="NO"
if [[ ${TRIGGER_ON_PACKAGE} -eq 1 ]]; then
    # We only get here if we are NOT doing an upgrade of the trigger package
    if [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -eq 1 ]]; then
        # We only get here if we are NOT doing an upgrade of the trigger package
        #                and we are installing _THIS_ package for the first time
        RUN_TRIGGER="Initial"
    elif [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -gt 1 ]]; then
        # We only get here if we are NOT doing an upgrade of the trigger package
        #                and we are upgrading _THIS_ package
        RUN_TRIGGER="UpgradeSELF"
    fi
elif [[ ${TRIGGER_ON_PACKAGE} -gt 1 ]]; then
    # We only get here if we are doing an upgrade of the trigger package
    if [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -eq 1 ]]; then
        # We get here if we are doing an upgrade of the trigger package
        #                     and we are NOT upgrading _THIS_ package
        RUN_TRIGGER="UpgradeTRIGGERON"

        #  But, are we installing _THIS_ package as a part of a dependency
        #       resolution chain?
        _THIS_TID=$(rpm -q --qf "%{INSTALLTID}\n" %{NAME})
        # Find the last installed (ie the current) TRIGGER_ON_PACKAGE_NAME's transaction
        TID=$(rpm -q --qf "%{INSTALLTID}\n" ${TRIGGER_ON_PACKAGE_NAME} --last |grep -v ${TRIGGER_ON_PACKAGE_NAME} | head -1)
        if [[ "${_THIS_TID}" == "${TID}" ]]; then
            # if the transaction ID of _THIS_ package is identical to the
            #  transaction ID of an installed TRIGGER_ON_PACKAGE_NAME
            # then, we must be upgrading the trigger package and
            # installing _THIS_ package
            RUN_TRIGGER="InitialSELFUpgradeTRIGGERON"
        fi
    elif [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -gt 1 ]]; then
        # We only get here if we are doing an upgrade of the trigger package
        #                     and we are upgrading _THIS_ package
        RUN_TRIGGER="UpgradeALL"
    fi
fi

if [[ "${RUN_TRIGGER}" == "NO" ]]; then
    # If we got here if:
    #  some kind of edge case appeared......
    echo "##################################" >&2
    echo "%{NAME}: Not sure what this means"  >&2
    echo "CURRENT_INSTALLS_OF_THIS_PACKAGE = ${CURRENT_INSTALLS_OF_THIS_PACKAGE}"  >&2
    echo "TRIGGER_ON_PACKAGE (${TRIGGER_ON_PACKAGE_NAME}) = ${TRIGGER_ON_PACKAGE}" >&2
    echo "##################################" >&2
    exit 1
fi

##################### End of Snippet #################################

if [[ "${RUN_TRIGGER}" == "UpgradeTRIGGERON" ]]; then
    # If we got here if:
    #  a) we are upgrading the trigger package, but not _THIS_ package
    #       so we've already run this once and will not run it again.

    # If the user changed the config themselves, we shouldn't undo their work
    #  if we decide we need to, we can always alter the behavior in the next
    #  version of this package.
    exit 0
fi


# # #
# This way external scripts/config tools can call these changes if they want
%{_libexecdir}/%{name}/%{name}.sh

%changelog
* Fri Oct 2 2015 Pat Riehecky <riehecky@fnal.gov> 1.0-1
- Initial build for EL7

